import unittest
from myFitter import *

def relDev(a, b):
    return 0.0 if a == b == 0.0 else 2.0*(a-b)/(abs(a)+abs(b))

class MyModel(Model):
    def __init__(self):
        Model.__init__(self)

        self.addParameter('p1', generator=lambda: random.gauss(0.0,1.0))
        self.addParameter('p2', generator=lambda: random.gauss(0.0,1.0))

        self.addGaussianCSC('o1', 0.0, 1.0)
        self.addGaussianCSC('o2', 0.0, 1.0)
        self.addGaussianCSC('o3', 1.0, 1.0)

    def getDependentQuantities(self, p):
        q = Model.getDependentQuantities(self, p)

        q['o1'] = q['p1']
        q['o2'] = q['p2']
        q['o3'] = -q['p1']**2 - q['p2']**2
        q['p1p2'] = q['p1']*q['p2']

        return q

class FitterTest(unittest.TestCase):
    def setUp(self):
        random.seed(1234)

    def test_fitter(self):
        model = MyModel()
        fitter = Fitter(model)
        fitter.sample(20)
        pp = fitter.nnearest({'o1':0.0, 'o2':0.0, 'o3':1.0}, 3)
        p0 = pp[0]
        for p in pp[1:]:
            for k in p0:
                p[k] = p[k] - p0[k]

